function varargout = more_temp(varargin)
% MORE_TEMP M-file for more_temp.fig
%      MORE_TEMP, by itself, creates a new MORE_TEMP or raises the existing
%      singleton*.
%
%      H = MORE_TEMP returns the handle to a new MORE_TEMP or the handle to
%      the existing singleton*.
%
%      MORE_TEMP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in MORE_TEMP.M with the given input arguments.
%
%      MORE_TEMP('Property','Value',...) creates a new MORE_TEMP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before more_temp_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to more_temp_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help more_temp

% Last Modified by GUIDE v2.5 16-May-2013 18:15:52

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @more_temp_OpeningFcn, ...
                   'gui_OutputFcn',  @more_temp_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before more_temp is made visible.
function more_temp_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to more_temp (see VARARGIN)
omtp = cell2mat(varargin(1));
% Choose default command line output for more_temp
handles.output = hObject;
handles.omtp=omtp;
% Update handles structure
guidata(hObject, handles);

% UIWAIT makes more_temp wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = more_temp_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
set(handles.text3, 'String', handles.omtp );


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close


% --------------------------------------------------------------------
function Untitled_1_Callback(hObject, eventdata, handles)
% hObject    handle to Untitled_1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
